otzyvru\_com package
====================

Submodules
----------

otzyvru\_com.cli module
-----------------------

.. automodule:: otzyvru_com.cli
    :members:
    :undoc-members:
    :show-inheritance:

otzyvru\_com.otzyvru\_com module
--------------------------------

.. automodule:: otzyvru_com.otzyvru_com
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: otzyvru_com
    :members:
    :undoc-members:
    :show-inheritance:
